@@ -1,20 +1,9 @@
-/***************************************************************************
-                          filters.cxx  -  description
-                             -------------------
-    begin                : Fri Jun 30 2000
-    copyright            : (C) 2000 by Hans Dijkema
-    email                : kmailcvt@hum.org
- ***************************************************************************/
+/*
+  SPDX-FileCopyrightText: 2000 Hans Dijkema <kmailcvt@hum.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-/* Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>                      */
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterinfo.h"
 #include "filterinfogui.h"
